@@ -241,8 +241,23 @@ class Accessible(BaseProxy):
                 return self.getChildCount()
 
         def __getitem__(self, index):
+                """
+                Thin wrapper around getChildAtIndex.
+                
+                @param index: Index of desired child
+                @type index: integer
+                @return: Accessible child
+                @rtype: Accessibility.Accessible
+                """
+                n = self.childCount
+                if index >= n:
+                        raise IndexError
+                elif index < -n:
+                        raise IndexError
+                elif index < 0:
+                        index += n
                 return self.getChildAtIndex(index)
-
+            
         # Bonobo interface --------------------------------------------------------------
 
         def queryInterface(self, interface):
@@ -263,6 +278,8 @@ class Accessible(BaseProxy):
 
         @property
 	def cached (self):
+                if not(registry.Registry().started):
+                        return False
                 if self._cache is not None:
 		        return (self.app_name, self.acc_path) in self._cache
                 else:
@@ -334,9 +351,6 @@ class Accessible(BaseProxy):
                 if self.cached and not(self._cached_data.state[0] & (1 << STATE_MANAGES_DESCENDANTS)):
                         (name, path) = self._cached_data.children[index]
                 else:
-                        count = Int32(self._pgetter(ATSPI_ACCESSIBLE, "ChildCount"))
-                        if index >= count:
-                                raise IndexError
                         func = self.get_dbus_method("GetChildAtIndex", dbus_interface=ATSPI_ACCESSIBLE)
                         (name, path) = func (index)
 
@@ -418,7 +432,10 @@ class Accessible(BaseProxy):
                         return _marshal_state_set(self._cached_data.state)
                 else:
                         func = self.get_dbus_method("GetState", dbus_interface=ATSPI_ACCESSIBLE)
-                        return _marshal_state_set(func())
+                        try:
+                                return _marshal_state_set(func())
+                        except LookupError:
+                                return _marshal_state_set ([1 << STATE_DEFUNCT, 0])
 
         def isEqual(self, other):
                 """
